Documentation
¶
Overview ¶
Package util provides shared filesystem utility functions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FileExists ¶
FileExists returns true if path exists and is a regular file.
Types ¶
type PathEscapeError ¶
PathEscapeError indicates an attempt to escape the base directory.
func (*PathEscapeError) Error ¶
func (e *PathEscapeError) Error() string
Click to show internal directories.
Click to hide internal directories.